# isEven

isEven is a simple library to check if a number is even.

### Installation

```
pip install isEven
```

### Usage

```
from isEven import isEven

print(isEven('1')) //=> False
print(isEven('5')) //=> False

print(isEven(0)) //=> True
print(isEven(4)) //=> True
```
